#define VERSION      "2.0.5"
#define LONG_VERSION "2.0.5 (13 September 2000)"
#define COPYLEFT     "(c) 1995, Eirik End\n(c) 1996-2000, Nicolas Hadacek"
#define EMAIL        "hadacek@kde.org"
#define HOMEPAGE     "http://azhyd.free.fr/KDE/ksirtet.php3"

#define TL_MULTIPLAYER_ID "003"
#define FE_MULTIPLAYER_ID "001"
